@@ -5,6 +5,6 @@ fn main() {
 
     tonic_build::configure()
         .out_dir(out_dir)
-        .compile(&["proto/upload.proto"],&["proto"])
+        .compile(&["proto/zhiyan.proto"],&["proto"])
         .unwrap();
 }
\ No newline at end of file
