@@ -1,13 +1,13 @@
 mod agent_conf;
 mod mod_conf;
-mod zhiyan_proto;
+mod zhiyan;
 
 use serde_json::Value;
 use std::{fs, thread, time::Duration};
 use tokio::runtime::Builder;
 use tonic::Request;
-use zhiyan_proto::upload_client::UploadClient;
-use zhiyan_proto::UploadRequest;
+use zhiyan::zhi_yan_client::ZhiYanClient;
+use zhiyan::ZhiYanRequest;
 
 pub fn path_exists(path: &str) -> bool {
     fs::metadata(path).is_ok()
@@ -26,27 +26,22 @@ pub fn send_request_json(json_value: Value) -> Result<(), ureq::Error> {
     }
 }
 
-pub fn mod_send_request_grpc(
-    name: String,
-    datetime: i64,
-    content: Vec<f32>,
-    conf_filename: String,
-) {
+pub fn mod_send_request_grpc(name: String, datetime: i64, content: String, conf_filename: String) {
     let mod_conf = mod_conf::load_mod_conf(&conf_filename.to_string()).unwrap();
 
     let run_time = Builder::new_multi_thread().enable_all().build().unwrap();
     run_time.block_on(async {
-        let mut client = UploadClient::connect(mod_conf.agent_url.clone())
+        let mut client = ZhiYanClient::connect(mod_conf.agent_url.clone())
             .await
             .unwrap();
 
-        let request = Request::new(UploadRequest {
+        let request = Request::new(ZhiYanRequest {
             name: name.clone(),
             datetime: datetime.clone(),
             content: content.clone(),
         });
 
-        let response = client.data_upload(request).await.unwrap();
+        let response = client.zymod(request).await.unwrap();
         let upload_response = response.get_ref();
         println!(
             "Code:{:?}\tMessages{:?}",
@@ -59,22 +54,22 @@ pub fn mod_send_request_grpc(
 pub fn agent_send_request_grpc(
     name: String,
     datetime: i64,
-    content: Vec<f32>,
+    content: String,
     conf_filename: String,
 ) {
     let agent_conf = agent_conf::load_agent_conf(&conf_filename.to_string()).unwrap();
 
     let run_time = Builder::new_multi_thread().enable_all().build().unwrap();
     run_time.spawn(async move {
-        let mut client = UploadClient::connect(agent_conf.server_url).await.unwrap();
+        let mut client = ZhiYanClient::connect(agent_conf.server_url).await.unwrap();
 
-        let request = Request::new(UploadRequest {
+        let request = Request::new(ZhiYanRequest {
             name: name.clone(),
             datetime: datetime.clone(),
             content: content.clone(),
         });
 
-        let response = client.data_upload(request).await.unwrap();
+        let response = client.zymod(request).await.unwrap();
         let upload_response = response.get_ref();
         println!("{:?}\n{:?}", upload_response.code, upload_response.message);
     });
